@@ -7,11 +7,12 @@ from scaled.io.config import (
     DEFAULT_IO_THREADS,
     DEFAULT_FUNCTION_RETENTION_SECONDS,
     DEFAULT_LOAD_BALANCE_SECONDS,
-    DEFAULT_LOAD_BALANCE_TRIGGER_TIMES, DEFAULT_MAX_NUMBER_OF_TASKS_WAITING,
+    DEFAULT_LOAD_BALANCE_TRIGGER_TIMES,
+    DEFAULT_MAX_NUMBER_OF_TASKS_WAITING,
     DEFAULT_PER_WORKER_QUEUE_SIZE,
     DEFAULT_WORKER_TIMEOUT_SECONDS,
 )
-from scaled.scheduler.main import Scheduler
+from scaled.scheduler.main import Scheduler, scheduler_main
 from scaled.utility.event_loop import EventLoopType, register_event_loop
 from scaled.utility.zmq_config import ZMQConfig
 from scaled.utility.logging.utility import setup_logger
@@ -74,21 +75,22 @@ def main():
     args = get_args()
     setup_logger()
 
-    scheduler = Scheduler(
-        address=args.address,
-        io_threads=args.io_threads,
-        max_number_of_tasks_waiting=args.max_number_of_tasks_waiting,
-        per_worker_queue_size=args.per_worker_queue_size,
-        worker_timeout_seconds=args.worker_timeout_seconds,
-        function_retention_seconds=args.function_retention_seconds,
-        load_balance_seconds=args.load_balance_seconds,
-        load_balance_trigger_times=args.load_balance_trigger_times,
-    )
     register_event_loop(args.event_loop)
 
     loop = asyncio.get_event_loop()
     __register_signal(loop)
-    loop.run_until_complete(scheduler.get_loops())
+    loop.run_until_complete(
+        scheduler_main(
+            address=args.address,
+            io_threads=args.io_threads,
+            max_number_of_tasks_waiting=args.max_number_of_tasks_waiting,
+            per_worker_queue_size=args.per_worker_queue_size,
+            worker_timeout_seconds=args.worker_timeout_seconds,
+            function_retention_seconds=args.function_retention_seconds,
+            load_balance_seconds=args.load_balance_seconds,
+            load_balance_trigger_times=args.load_balance_trigger_times,
+        )
+    )
 
 
 def __register_signal(loop):
