@@ -1,7 +1,16 @@
 import abc
-from typing import Dict
+from typing import Dict, Optional, Set
 
-from scaled.protocol.python.message import FunctionRequest, Heartbeat, Task, TaskCancel, TaskCancelEcho, TaskResult
+from scaled.protocol.python.message import (
+    BalanceResponse,
+    DisconnectRequest,
+    FunctionRequest,
+    Heartbeat,
+    Task,
+    TaskCancel,
+    TaskCancelEcho,
+    TaskResult,
+)
 
 
 class Looper(metaclass=abc.ABCMeta):
@@ -9,6 +18,8 @@ class Looper(metaclass=abc.ABCMeta):
     async def routine(self):
         raise NotImplementedError()
 
+
+class Reporter(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     async def statistics(self) -> Dict:
         raise NotImplementedError()
@@ -34,15 +45,19 @@ class FunctionManager(metaclass=abc.ABCMeta):
 
 class ClientManager(metaclass=abc.ABCMeta):
     @abc.abstractmethod
-    async def on_task_new(self, client: bytes, task: Task):
+    def get_client_task_ids(self, client: bytes) -> Set[bytes]:
         raise NotImplementedError()
 
     @abc.abstractmethod
-    async def on_task_cancel(self, client: bytes, task_id: bytes):
+    def get_client_id(self, task_id: bytes) -> Optional[bytes]:
         raise NotImplementedError()
 
     @abc.abstractmethod
-    async def on_task_done(self, result: TaskResult):
+    async def on_task_new(self, client: bytes, task_id: bytes):
+        raise NotImplementedError()
+
+    @abc.abstractmethod
+    async def on_task_done(self, task_id: bytes) -> bytes:
         raise NotImplementedError()
 
 
@@ -85,6 +100,10 @@ class WorkerManager(metaclass=abc.ABCMeta):
     async def on_task_cancel_echo(self, worker: bytes, task_cancel_echo: TaskCancelEcho):
         raise NotImplementedError()
 
+    @abc.abstractmethod
+    async def on_balance_response(self, response: BalanceResponse):
+        raise NotImplementedError()
+
     @abc.abstractmethod
     async def on_task_done(self, task_result: TaskResult):
         raise NotImplementedError()
@@ -92,3 +111,7 @@ class WorkerManager(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     async def on_heartbeat(self, worker: bytes, info: Heartbeat):
         raise NotImplementedError()
+
+    @abc.abstractmethod
+    async def on_disconnect(self, source: bytes, request: DisconnectRequest):
+        raise NotImplementedError()
