@@ -7,6 +7,7 @@ from attrs.validators import instance_of, optional
 
 class ZMQType(enum.Enum):
     inproc = "inproc"
+    ipc = "ipc"
     tcp = "tcp"
 
 
@@ -24,8 +25,8 @@ class ZMQConfig:
         if self.type == ZMQType.tcp:
             return f"tcp://{self.host}:{self.port}"
 
-        if self.type == ZMQType.inproc:
-            return f"inproc://{self.host}"
+        if self.type in {ZMQType.inproc, ZMQType.ipc}:
+            return f"{self.type.value}://{self.host}"
 
         raise TypeError(f"Unsupported ZMQ type: {self.type}")
 
@@ -35,8 +36,15 @@ class ZMQConfig:
             raise ValueError(f"valid ZMQ config should be like tcp://127.0.0.1:12345")
 
         socket_type, host_port = string.split("://", 1)
-        if socket_type not in {member.value for member in ZMQType}:
-            raise ValueError(f"supported ZMQ types are: {[member.value for member in ZMQType]}")
+        allowed_types = {member.value for member in ZMQType}
+        if socket_type not in allowed_types:
+            raise ValueError(f"supported ZMQ types are: {allowed_types}")
+
+        socket_type = ZMQType(socket_type)
+        if socket_type in {ZMQType.inproc, ZMQType.ipc}:
+            host = host_port
+            port = 0
+        else:
+            host, port = host_port.split(":")
 
-        host, port = host_port.split(":")
         return ZMQConfig(ZMQType(socket_type), host, int(port))
